==> kopete-4.14.3-i586-2.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf libkopete_videodevice.so )
( cd usr/lib ; ln -sf libkopete_videodevice.so.4 libkopete_videodevice.so )
( cd usr/lib ; rm -rf liboscar.so.1 )
( cd usr/lib ; ln -sf liboscar.so.1.0.0 liboscar.so.1 )
( cd usr/lib ; rm -rf libkopeteaddaccountwizard.so )
( cd usr/lib ; ln -sf libkopeteaddaccountwizard.so.1 libkopeteaddaccountwizard.so )
( cd usr/lib ; rm -rf libkopeteaddaccountwizard.so.1 )
( cd usr/lib ; ln -sf libkopeteaddaccountwizard.so.1.0.0 libkopeteaddaccountwizard.so.1 )
( cd usr/lib ; rm -rf libkirc.so )
( cd usr/lib ; ln -sf libkirc.so.1 libkirc.so )
( cd usr/lib ; rm -rf libkopetechatwindow_shared.so )
( cd usr/lib ; ln -sf libkopetechatwindow_shared.so.1 libkopetechatwindow_shared.so )
( cd usr/lib ; rm -rf libkopeteprivacy.so )
( cd usr/lib ; ln -sf libkopeteprivacy.so.1 libkopeteprivacy.so )
( cd usr/lib ; rm -rf libkopete_oscar.so )
( cd usr/lib ; ln -sf libkopete_oscar.so.4 libkopete_oscar.so )
( cd usr/lib ; rm -rf libkopetechatwindow_shared.so.1 )
( cd usr/lib ; ln -sf libkopetechatwindow_shared.so.1.0.0 libkopetechatwindow_shared.so.1 )
( cd usr/lib ; rm -rf libkopete.so )
( cd usr/lib ; ln -sf libkopete.so.4 libkopete.so )
( cd usr/lib ; rm -rf libkopete_oscar.so.4 )
( cd usr/lib ; ln -sf libkopete_oscar.so.4.14.13 libkopete_oscar.so.4 )
( cd usr/lib ; rm -rf libkirc_client.so )
( cd usr/lib ; ln -sf libkirc_client.so.1 libkirc_client.so )
( cd usr/lib ; rm -rf libkopete_videodevice.so.4 )
( cd usr/lib ; ln -sf libkopete_videodevice.so.4.14.13 libkopete_videodevice.so.4 )
( cd usr/lib ; rm -rf libkyahoo.so )
( cd usr/lib ; ln -sf libkyahoo.so.1 libkyahoo.so )
( cd usr/lib ; rm -rf libkyahoo.so.1 )
( cd usr/lib ; ln -sf libkyahoo.so.1.0.0 libkyahoo.so.1 )
( cd usr/lib ; rm -rf libkopete.so.4 )
( cd usr/lib ; ln -sf libkopete.so.4.14.13 libkopete.so.4 )
( cd usr/lib ; rm -rf libkirc.so.1 )
( cd usr/lib ; ln -sf libkirc.so.1.0.0 libkirc.so.1 )
( cd usr/lib ; rm -rf libkirc_client.so.1 )
( cd usr/lib ; ln -sf libkirc_client.so.1.0.0 libkirc_client.so.1 )
( cd usr/lib ; rm -rf libkopetestatusmenu.so.1 )
( cd usr/lib ; ln -sf libkopetestatusmenu.so.1.0.0 libkopetestatusmenu.so.1 )
( cd usr/lib ; rm -rf libkopeteidentity.so.1 )
( cd usr/lib ; ln -sf libkopeteidentity.so.1.0.0 libkopeteidentity.so.1 )
( cd usr/lib ; rm -rf liboscar.so )
( cd usr/lib ; ln -sf liboscar.so.1 liboscar.so )
( cd usr/lib ; rm -rf libkopeteprivacy.so.1 )
( cd usr/lib ; ln -sf libkopeteprivacy.so.1.0.0 libkopeteprivacy.so.1 )
( cd usr/lib ; rm -rf libkopetecontactlist.so )
( cd usr/lib ; ln -sf libkopetecontactlist.so.1 libkopetecontactlist.so )
( cd usr/lib ; rm -rf libkopetestatusmenu.so )
( cd usr/lib ; ln -sf libkopetestatusmenu.so.1 libkopetestatusmenu.so )
( cd usr/lib ; rm -rf libkopetecontactlist.so.1 )
( cd usr/lib ; ln -sf libkopetecontactlist.so.1.0.0 libkopetecontactlist.so.1 )
( cd usr/lib ; rm -rf libkopeteidentity.so )
( cd usr/lib ; ln -sf libkopeteidentity.so.1 libkopeteidentity.so )
( cd usr/doc/HTML/en/kopete ; rm -rf common )
( cd usr/doc/HTML/en/kopete ; ln -sf /usr/share/doc/HTML/en/common common )

==> kopete-23.08.5-i586-1.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf libkopete.so )
( cd usr/lib ; ln -sf libkopete.so.1 libkopete.so )
( cd usr/lib ; rm -rf libkopete.so.1 )
( cd usr/lib ; ln -sf libkopete.so.1.0.0 libkopete.so.1 )
( cd usr/lib ; rm -rf libkopete_oscar.so )
( cd usr/lib ; ln -sf libkopete_oscar.so.1 libkopete_oscar.so )
( cd usr/lib ; rm -rf libkopete_oscar.so.1 )
( cd usr/lib ; ln -sf libkopete_oscar.so.1.0.0 libkopete_oscar.so.1 )
( cd usr/lib ; rm -rf libkopete_videodevice.so )
( cd usr/lib ; ln -sf libkopete_videodevice.so.1 libkopete_videodevice.so )
( cd usr/lib ; rm -rf libkopete_videodevice.so.1 )
( cd usr/lib ; ln -sf libkopete_videodevice.so.1.0.0 libkopete_videodevice.so.1 )
( cd usr/lib ; rm -rf libkopeteaddaccountwizard.so )
( cd usr/lib ; ln -sf libkopeteaddaccountwizard.so.1 libkopeteaddaccountwizard.so )
( cd usr/lib ; rm -rf libkopeteaddaccountwizard.so.1 )
( cd usr/lib ; ln -sf libkopeteaddaccountwizard.so.1.0.0 libkopeteaddaccountwizard.so.1 )
( cd usr/lib ; rm -rf libkopetechatwindow_shared.so )
( cd usr/lib ; ln -sf libkopetechatwindow_shared.so.1 libkopetechatwindow_shared.so )
( cd usr/lib ; rm -rf libkopetechatwindow_shared.so.1 )
( cd usr/lib ; ln -sf libkopetechatwindow_shared.so.1.0.0 libkopetechatwindow_shared.so.1 )
( cd usr/lib ; rm -rf libkopetecontactlist.so )
( cd usr/lib ; ln -sf libkopetecontactlist.so.1 libkopetecontactlist.so )
( cd usr/lib ; rm -rf libkopetecontactlist.so.1 )
( cd usr/lib ; ln -sf libkopetecontactlist.so.1.0.0 libkopetecontactlist.so.1 )
( cd usr/lib ; rm -rf libkopeteidentity.so )
( cd usr/lib ; ln -sf libkopeteidentity.so.1 libkopeteidentity.so )
( cd usr/lib ; rm -rf libkopeteidentity.so.1 )
( cd usr/lib ; ln -sf libkopeteidentity.so.1.0.0 libkopeteidentity.so.1 )
( cd usr/lib ; rm -rf libkopeteprivacy.so )
( cd usr/lib ; ln -sf libkopeteprivacy.so.1 libkopeteprivacy.so )
( cd usr/lib ; rm -rf libkopeteprivacy.so.1 )
( cd usr/lib ; ln -sf libkopeteprivacy.so.1.0.0 libkopeteprivacy.so.1 )
( cd usr/lib ; rm -rf libkopetestatusmenu.so )
( cd usr/lib ; ln -sf libkopetestatusmenu.so.1 libkopetestatusmenu.so )
( cd usr/lib ; rm -rf libkopetestatusmenu.so.1 )
( cd usr/lib ; ln -sf libkopetestatusmenu.so.1.0.0 libkopetestatusmenu.so.1 )
( cd usr/lib ; rm -rf liboscar.so )
( cd usr/lib ; ln -sf liboscar.so.1 liboscar.so )
( cd usr/lib ; rm -rf liboscar.so.1 )
( cd usr/lib ; ln -sf liboscar.so.1.0.0 liboscar.so.1 )
